==> lowcode-shell-1.0.0-beta.8.tgz: package/es/project.js <==
import _createClass from "@babel/runtime/helpers/createClass";
import DocumentModel from './document-model';
import SimulatorHost from './simulator-host';
import { projectSymbol, simulatorHostSymbol, simulatorRendererSymbol } from './symbols';

var Project = /*#__PURE__*/function () {
  function Project(project) {
    this[projectSymbol] = void 0;
    this[simulatorHostSymbol] = void 0;
    this[simulatorRendererSymbol] = void 0;
    this[projectSymbol] = project;
  }

  Project.create = function create(project) {
    return new Project(project);
  }
  /**
   * 获取当前的 document
   * @returns
   */
  ;

  var _proto = Project.prototype;

  /**
   * 打开一个 document
   * @param doc
   * @returns
   */
  _proto.openDocument = function openDocument(doc) {
    var documentModel = this[projectSymbol].open(doc);
    if (!documentModel) return null;
    return DocumentModel.create(documentModel);
  }
  /**
   * 创建一个 document
   * @param data
   * @returns
   */
  ;

  _proto.createDocument = function createDocument(data) {
    var doc = this[projectSymbol].createDocument(data);
    return DocumentModel.create(doc);
  }
  /**
   * 根据 fileName 获取 document
   * @param fileName
   * @returns
   */
  ;

  _proto.getDocumentByFileName = function getDocumentByFileName(fileName) {
    return DocumentModel.create(this[projectSymbol].getDocumentByFileName(fileName));
  }
  /**
   * 根据 id 获取 document
   * @param id
   * @returns
   */
  ;

  _proto.getDocumentById = function getDocumentById(id) {
    return DocumentModel.create(this[projectSymbol].getDocument(id));
  }
  /**
   * 导出 project
   * @returns
   */
  ;

  _proto.exportSchema = function exportSchema() {
    return this[projectSymbol].getSchema();
  }
  /**
   * 导入 project
   * @param schema 待导入的 project 数据
   */
  ;

  _proto.importSchema = function importSchema(schema) {
    this[projectSymbol].load(schema, true);
  }
  /**
   * 获取当前的 document
   * @returns
   */
  ;

  _proto.getCurrentDocument = function getCurrentDocument() {
    return DocumentModel.create(this[projectSymbol].currentDocument);
  }
  /**
   * 增加一个属性的管道处理函数
   * @param transducer
   * @param stage
   */
  ;

  _proto.addPropsTransducer = function addPropsTransducer(transducer, stage) {
    this[projectSymbol].designer.addPropsReducer(transducer, stage);
  }
  /**
   * 当前 project 内的 document 变更事件
   */
  ;

  _proto.onChangeDocument = function onChangeDocument(fn) {
    if (this[projectSymbol].currentDocument) {
      fn(DocumentModel.create(this[projectSymbol].currentDocument));
      return function () {};
    }

    return this[projectSymbol].onCurrentDocumentChange(function (originalDoc) {
      fn(DocumentModel.create(originalDoc));
    });
  }
  /**
   * 当前 project 的模拟器 ready 事件
   */
  ;

  _proto.onSimulatorHostReady = function onSimulatorHostReady(fn) {
    var _this = this;

    if (this[simulatorHostSymbol]) {
      fn(SimulatorHost.create(this[simulatorHostSymbol]));
      return function () {};
    }

    return this[projectSymbol].onSimulatorReady(function (simulator) {
      _this[simulatorHostSymbol] = simulator;
      fn(SimulatorHost.create(simulator));
    });
  }
  /**
   * 当前 project 的渲染器 ready 事件
   */
  ;

  _proto.onSimulatorRendererReady = function onSimulatorRendererReady(fn) {
    var _this2 = this;

    if (this[simulatorRendererSymbol]) {
      fn();
      return function () {};
    } // TODO: 补充 renderer 实例


    return this[projectSymbol].onRendererReady(function (renderer) {
      _this2[simulatorRendererSymbol] = renderer;
      fn();
    });
  };

  _createClass(Project, [{
    key: "currentDocument",
    get: function get() {
      return this.getCurrentDocument();
    }
    /**
     * 获取当前 project 下所有 documents
     * @returns
     */

  }, {
    key: "documents",
    get: function get() {
      return this[projectSymbol].documents.map(function (doc) {
        return DocumentModel.create(doc);
      });
    }
    /**
     * 获取模拟器的 host
     */

  }, {
    key: "simulatorHost",
    get: function get() {
      return SimulatorHost.create(this[projectSymbol].simulator || this[simulatorHostSymbol]);
    }
    /**
     * @deprecated use .simulatorHost instead.
     */

  }, {
    key: "simulator",
    get: function get() {
      return this.simulatorHost;
    }
  }]);

  return Project;
}();

export { Project as default };

==> lowcode-shell-1.0.10-beta.8.tgz: package/es/project.js <==
import _createClass from "@babel/runtime/helpers/createClass";
import { TransformStage } from '@alilc/lowcode-designer';
import DocumentModel from './document-model';
import SimulatorHost from './simulator-host';
import { projectSymbol, simulatorHostSymbol, simulatorRendererSymbol, documentSymbol } from './symbols';

var Project = /*#__PURE__*/function () {
  function Project(project) {
    this[projectSymbol] = void 0;
    this[simulatorHostSymbol] = void 0;
    this[simulatorRendererSymbol] = void 0;
    this[projectSymbol] = project;
  }

  Project.create = function create(project) {
    return new Project(project);
  }
  /**
   * 获取当前的 document
   * @returns
   */
  ;

  var _proto = Project.prototype;

  /**
   * 打开一个 document
   * @param doc
   * @returns
   */
  _proto.openDocument = function openDocument(doc) {
    var documentModel = this[projectSymbol].open(doc);
    if (!documentModel) return null;
    return DocumentModel.create(documentModel);
  }
  /**
   * 创建一个 document
   * @param data
   * @returns
   */
  ;

  _proto.createDocument = function createDocument(data) {
    var doc = this[projectSymbol].createDocument(data);
    return DocumentModel.create(doc);
  }
  /**
   * 删除一个 document
   * @param doc
   */
  ;

  _proto.removeDocument = function removeDocument(doc) {
    this[projectSymbol].removeDocument(doc[documentSymbol]);
  }
  /**
   * 根据 fileName 获取 document
   * @param fileName
   * @returns
   */
  ;

  _proto.getDocumentByFileName = function getDocumentByFileName(fileName) {
    return DocumentModel.create(this[projectSymbol].getDocumentByFileName(fileName));
  }
  /**
   * 根据 id 获取 document
   * @param id
   * @returns
   */
  ;

  _proto.getDocumentById = function getDocumentById(id) {
    return DocumentModel.create(this[projectSymbol].getDocument(id));
  }
  /**
   * 导出 project
   * @returns
   */
  ;

  _proto.exportSchema = function exportSchema(stage) {
    if (stage === void 0) {
      stage = TransformStage.Render;
    }

    return this[projectSymbol].getSchema(stage);
  }
  /**
   * 导入 project
   * @param schema 待导入的 project 数据
   */
  ;

  _proto.importSchema = function importSchema(schema) {
    this[projectSymbol].load(schema, true);
  }
  /**
   * 获取当前的 document
   * @returns
   */
  ;

  _proto.getCurrentDocument = function getCurrentDocument() {
    return DocumentModel.create(this[projectSymbol].currentDocument);
  }
  /**
   * 增加一个属性的管道处理函数
   * @param transducer
   * @param stage
   */
  ;

  _proto.addPropsTransducer = function addPropsTransducer(transducer, stage) {
    this[projectSymbol].designer.addPropsReducer(transducer, stage);
  }
  /**
   * 当前 project 内的 document 变更事件
   */
  ;

  _proto.onChangeDocument = function onChangeDocument(fn) {
    if (this[projectSymbol].currentDocument) {
      fn(DocumentModel.create(this[projectSymbol].currentDocument));
      return function () {};
    }

    return this[projectSymbol].onCurrentDocumentChange(function (originalDoc) {
      fn(DocumentModel.create(originalDoc));
    });
  }
  /**
   * 当前 project 的模拟器 ready 事件
   */
  ;

  _proto.onSimulatorHostReady = function onSimulatorHostReady(fn) {
    var _this = this;

    if (this[simulatorHostSymbol]) {
      fn(SimulatorHost.create(this[simulatorHostSymbol]));
      return function () {};
    }

    return this[projectSymbol].onSimulatorReady(function (simulator) {
      _this[simulatorHostSymbol] = simulator;
      fn(SimulatorHost.create(simulator));
    });
  }
  /**
   * 当前 project 的渲染器 ready 事件
   */
  ;

  _proto.onSimulatorRendererReady = function onSimulatorRendererReady(fn) {
    var _this2 = this;

    if (this[simulatorRendererSymbol]) {
      fn();
      return function () {};
    } // TODO: 补充 renderer 实例


    return this[projectSymbol].onRendererReady(function (renderer) {
      _this2[simulatorRendererSymbol] = renderer;
      fn();
    });
  };

  _createClass(Project, [{
    key: "currentDocument",
    get: function get() {
      return this.getCurrentDocument();
    }
    /**
     * 获取当前 project 下所有 documents
     * @returns
     */

  }, {
    key: "documents",
    get: function get() {
      return this[projectSymbol].documents.map(function (doc) {
        return DocumentModel.create(doc);
      });
    }
    /**
     * 获取模拟器的 host
     */

  }, {
    key: "simulatorHost",
    get: function get() {
      return SimulatorHost.create(this[projectSymbol].simulator || this[simulatorHostSymbol]);
    }
    /**
     * @deprecated use .simulatorHost instead.
     */

  }, {
    key: "simulator",
    get: function get() {
      return this.simulatorHost;
    }
  }]);

  return Project;
}();

export { Project as default };
